@@ -49,6 +49,10 @@ Any other value means use `view-buffer-other-window'."
 		(sexp :format "%t\n" :tag "View-mode other window" other))
   :group 'man)
 
+(defcustom Manual-switches nil
+  "List of switches to the man program."
+  :type '(list string))
+
 (defcustom Manual-mode-hook nil
   "Function or functions run on entry to Manual-mode."
   :type 'hook
@@ -230,7 +234,7 @@ potentially taking a long time."
 		   (setq buffer-read-only nil)
 		   (erase-buffer)
 
-		   (let ((args (list topic))
+		   (let ((args (append Manual-switches (list topic)))
 			 args-string)
 		     (if section
 			 (setq args
@@ -311,6 +315,7 @@ potentially taking a long time."
   (list 'delete-region '(point) (list '+ '(point) n)))
 
 ;; Hint: BS stands for more things than "back space"
+;;;###autoload
 (defun Manual-nuke-nroff-bs (&optional apropos-mode)
   (interactive "*")
   (if Manual-use-rosetta-man
@@ -403,7 +408,8 @@ potentially taking a long time."
   (Manual-mouseify-xrefs)
   )
 
-(fset 'nuke-nroff-bs 'Manual-nuke-nroff-bs) ; use old name
+;;;###autoload
+(defalias 'nuke-nroff-bs 'Manual-nuke-nroff-bs) ; use old name
 
 
 (defun Manual-nuke-nroff-bs-footers ()
