@@ -624,7 +624,7 @@ Only the first matching regexp/replacement pair is applied."
   "Add file FILENAME to `recent-files-list'.
 FILENAME is not really added if it matches one of the regexps in
 `recent-files-dont-include'."
-  (if (recent-files-no-match filename recent-files-dont-include)
+  (if (and filename (recent-files-no-match filename recent-files-dont-include))
       (progn
 	(setq recent-files-list-changed-p t)
 	(setq recent-files-list
